#
# Conditional build:
%bcond_without	gtk3		# GTK+ 3.x GUI library for nvidia-settings
%bcond_without	nvidia_settings	# build the main package
%bcond_without	utils		# build utils from samples dir
%bcond_without	libXNVCtrl	# build libXNVCtrl for external packages

Summary:	Tool for configuring the NVIDIA driver
Summary(pl.UTF-8):	Narzędzie do konfigurowania sterownika NVIDIA
Name:		nvidia-settings
# keep the version in sync with xorg-driver-video-nvidia.spec
Version:	570.153.02
Release:	1
License:	GPL v2 (with MIT parts)
Group:		X11/Applications
Source0:	https://download.nvidia.com/XFree86/nvidia-settings/%{name}-%{version}.tar.bz2
# Source0-md5:	4fcc45a9084db1207e3cabf33c7cb3ef
Source1:	%{name}.desktop
Source2:	%{name}.png
Source3:	%{name}-autostart.desktop
URL:		ftp://download.nvidia.com/XFree86/nvidia-settings/
BuildRequires:	OpenGL-devel
BuildRequires:	libvdpau-devel >= 1.0
BuildRequires:	xorg-lib-libX11-devel
BuildRequires:	xorg-lib-libXext-devel
BuildRequires:	xorg-lib-libXv-devel
BuildRequires:	xorg-lib-libXxf86vm-devel
%if %{with nvidia_settings}
BuildRequires:	gtk+2-devel >= 2.0
%{?with_gtk3:BuildRequires:	gtk+3-devel >= 3.0}
BuildRequires:	jansson-devel >= 2.2
BuildRequires:	m4
BuildRequires:	pkgconfig
BuildRequires:	wayland-devel
%endif
Requires(post,postun):	desktop-file-utils
Requires:	%{name}-guilib = %{version}-%{release}
Requires:	libvdpau >= 1.0
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# requires symbols from main binary
%define		skip_post_check_so	libnvidia-gtk[23].so.*

%if !%{with utils}
%define		_enable_debug_packages	0
%endif

%description
The nvidia-settings utility is a tool for configuring the NVIDIA Linux
graphics driver. It operates by communicating with the NVIDIA X
driver, querying and updating state as appropriate. This communication
is done with the NV-CONTROL X extension.

Values such as brightness and gamma, XVideo attributes, temperature,
and OpenGL settings can be queried and configured via nvidia-settings.

When nvidia-settings starts, it reads the current settings from its
configuration file and sends those settings to the X server. Then, it
displays a graphical user interface (GUI) interface for configuring
the current settings. When nvidia-settings exits, it queries the
current settings from the X server and saves them to the configuration
file.

%description -l pl.UTF-8
Narzędzie nvidia-settings służy do konfiguracji sterownika do kart
graficznych firmy NVIDIA. Działa komunikując się ze sterownikiem X
NVIDIA, sprawdzając i uaktualniając stan w razie potrzeby. Komunikacja
odbywa się poprzez rozszerzenie X NV-CONTROL.

Za pomocą nvidia-settings można odczytywać i zmieniać wartości takie
jak jasność i korekcja gamma, atrybuty XVideo, temperatura barw i
ustawienia OpenGL.

Przy uruchamianiu nvidia-settings odczytuje bieżące ustawienia z pliku
konfiguracyjnego i wysyła te ustawienia do serwera X. Następnie
wyświetla graficzny interfejs użytkownika (GUI) do konfiguracji
ustawień. Przy wyłączniu nvidia-settings odczytuje bieżące ustawienia
z serwera X i zapisuje je do pliku konfiguracyjnego.

%package gtk2
Summary:	GTK+ 2.x GUI library for nvidia-settings
Summary(pl.UTF-8):	Biblioteka interfejsu graficznego GTK+ 2.x dla nvidia-settings
Group:		X11/Libraries
Requires:	%{name} = %{version}-%{release}
Provides:	%{name}-guilib = %{version}-%{release}

%description gtk2
GTK+ 2.x GUI library for nvidia-settings.

%description gtk2 -l pl.UTF-8
Biblioteka interfejsu graficznego GTK+ 2.x dla nvidia-settings.

%package gtk3
Summary:	GTK+ 3.x GUI library for nvidia-settings
Summary(pl.UTF-8):	Biblioteka interfejsu graficznego GTK+ 3.x dla nvidia-settings
Group:		X11/Libraries
Requires:	%{name} = %{version}-%{release}
Provides:	%{name}-guilib = %{version}-%{release}

%description gtk3
GTK+ 3.x GUI library for nvidia-settings.

%description gtk3 -l pl.UTF-8
Biblioteka interfejsu graficznego GTK+ 3.x dla nvidia-settings.

%package -n libXNVCtrl-devel
Summary:	libXNVCtrl development files
Summary(pl.UTF-8):	Pliki programistyczne biblioteki libXNVCtrl
License:	MIT
Group:		Development/Libraries
Requires:	xorg-lib-libX11-devel
Requires:	xorg-lib-libXext-devel
Requires:	xorg-lib-libXxf86vm-devel
Obsoletes:	libXNVCtrl-static < 195.36.24

%description -n libXNVCtrl-devel
Library for accessing NV-CONTROL extension in NVIDIA's latest drivers.

%description -n libXNVCtrl-devel -l pl.UTF-8
Biblioteka do obsługi rozszerzenia NV-CONTROL z najnowszych
sterowników NVIDIA.

%prep
%setup -q

%build
%if %{with libXNVCtrl}
CFLAGS="%{rpmcppflags} %{rpmcflags} -fPIC" \
%{__make} -C src/libXNVCtrl \
	NV_VERBOSE=1 \
	CC="%{__cc}" \
	OUTPUTDIR=.
%endif

%if %{with utils}
CFLAGS="%{rpmcppflags} %{rpmcflags} -fPIC" \
%{__make} -C samples \
	NV_VERBOSE=1 \
	CC="%{__cc}" \
	OUTPUTDIR=$(pwd)/_out/utils \
%endif

%if %{with nvidia_settings}
CFLAGS="%{rpmcppflags} %{rpmcflags}" \
LDFLAGS="%{rpmldflags}" \
%{__make} -C src \
	%{!?with_gtk3:BUILD_GTK3LIB=} \
	NV_USE_BUNDLED_LIBJANSSON=0 \
	NV_VERBOSE=1 \
	STRIP_CMD=: \
	CC="%{__cc}"

%{__make} -C doc \
	NV_VERBOSE=1
%endif

%install
rm -rf $RPM_BUILD_ROOT
%if %{with nvidia_settings}
install -d $RPM_BUILD_ROOT{%{_bindir},%{_mandir}/man1,%{_desktopdir},%{_pixmapsdir},/etc/xdg/autostart}
%{__make} install \
	NV_USE_BUNDLED_LIBJANSSON=0 \
	NV_VERBOSE=1 \
	INSTALL="install -p" \
	LIBDIR="$RPM_BUILD_ROOT%{_libdir}" \
	PREFIX=%{_prefix} \
	DESTDIR=$RPM_BUILD_ROOT
cp -p %{SOURCE1} $RPM_BUILD_ROOT%{_desktopdir}
cp -p %{SOURCE2} $RPM_BUILD_ROOT%{_pixmapsdir}
cp -p %{SOURCE3} $RPM_BUILD_ROOT/etc/xdg/autostart/%{name}.desktop

# let RPM autogenerate deps
chmod 755 $RPM_BUILD_ROOT%{_libdir}/lib*.so*
%endif

%if %{with libXNVCtrl}
install -d $RPM_BUILD_ROOT%{_examplesdir}/libXNVCtrl-%{version} \
	$RPM_BUILD_ROOT{%{_libdir},%{_includedir}/NVCtrl}
cp -a samples/* $RPM_BUILD_ROOT%{_examplesdir}/libXNVCtrl-%{version}
cp -p src/libXNVCtrl/nv_control.h $RPM_BUILD_ROOT%{_includedir}/NVCtrl
cp -p src/libXNVCtrl/NVCtrl.h $RPM_BUILD_ROOT%{_includedir}/NVCtrl
cp -p src/libXNVCtrl/NVCtrlLib.h $RPM_BUILD_ROOT%{_includedir}/NVCtrl
cp -p src/libXNVCtrl/libXNVCtrl.a $RPM_BUILD_ROOT%{_libdir}

install -d $RPM_BUILD_ROOT%{_pkgconfigdir}
cat <<'EOF' > $RPM_BUILD_ROOT%{_pkgconfigdir}/libXNVCtrl.pc
prefix=%{_prefix}
libdir=%{_libdir}
includedir=${prefix}/include/NVCtrl

Name: libXNVCtrl
Description: Library for accessing NV-CONTROL extension in NVIDIA's latest drivers.
Version: %{version}
Libs: -L${libdir} -lXNVCtrl
Cflags: -I${includedir}
EOF
#'
%endif

%if %{with utils}
install -d $RPM_BUILD_ROOT%{_bindir}
for prog in _out/utils/nv-control-*; do
	case "$prog" in
	*.*)
		continue
		;;
	esac
	install -p $prog $RPM_BUILD_ROOT%{_bindir}
done
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig
%update_desktop_database_post

%postun
/sbin/ldconfig
%update_desktop_database_postun

%post	gtk2 -p /sbin/ldconfig
%postun	gtk2 -p /sbin/ldconfig

%post	gtk3 -p /sbin/ldconfig
%postun	gtk3 -p /sbin/ldconfig

%if %{with nvidia_settings}
%files
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/nvidia-settings
%if %{with utils}
%attr(755,root,root) %{_bindir}/nv-control-3dvisionpro
%attr(755,root,root) %{_bindir}/nv-control-dpy
%attr(755,root,root) %{_bindir}/nv-control-dvc
%attr(755,root,root) %{_bindir}/nv-control-events
%attr(755,root,root) %{_bindir}/nv-control-framelock
%attr(755,root,root) %{_bindir}/nv-control-info
%attr(755,root,root) %{_bindir}/nv-control-targets
%attr(755,root,root) %{_bindir}/nv-control-warpblend
%endif
%attr(755,root,root) %{_libdir}/libnvidia-wayland-client.so.*
%{_mandir}/man1/nvidia-settings.1*
%{_desktopdir}/nvidia-settings.desktop
%{_pixmapsdir}/nvidia-settings.png
/etc/xdg/autostart/%{name}.desktop

%files gtk2
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libnvidia-gtk2.so.%{version}

%if %{with gtk3}
%files gtk3
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libnvidia-gtk3.so.%{version}
%endif
%endif

%if %{with libXNVCtrl}
%files -n libXNVCtrl-devel
%defattr(644,root,root,755)
%doc doc/{FRAMELOCK,NV-CONTROL-API}.txt
%{_libdir}/libXNVCtrl.a
%{_includedir}/NVCtrl
%{_pkgconfigdir}/libXNVCtrl.pc
%{_examplesdir}/libXNVCtrl-%{version}
%endif
%changelog
* Sat Jun 21 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/nvidia-settings.git;a=log;h=master

* Sat Jun 21 2025 Jan Rękorajski <baggins@pld-linux.org> 6011833
- 570.153.02, sync with driver package

* Sat Apr 19 2025 Jan Rękorajski <baggins@pld-linux.org> 740ee9d
- up to 570.133.07

* Sun Jul 28 2024 Jan Palus <atler@pld-linux.org> 9d82881
- up to 550.100

* Fri Nov 24 2023 Jan Palus <atler@pld-linux.org> 8c548b3
- up to 545.29.06

* Tue Oct 31 2023 Jan Palus <atler@pld-linux.org> e4f2ce9
- up to 545.29.02

* Tue Sep 26 2023 Jan Palus <atler@pld-linux.org> 7d8b2fa
- up to 535.113.01

* Thu Aug 24 2023 Jan Palus <atler@pld-linux.org> 59c4e8f
- up to 535.104.05

* Tue Aug 08 2023 Jan Palus <atler@pld-linux.org> e3a40cf
- update desktop database

* Tue Aug 08 2023 Jan Palus <atler@pld-linux.org> b5b624d
- up to 535.98

* Thu Jul 20 2023 Jan Palus <atler@pld-linux.org> b4acb09
- up to 535.86.05

* Thu Jul 20 2023 Marcin Krol <hawk@tld-linux.org> f87abd9
- fix building w/o utils on rpm.org

* Wed Jun 14 2023 Jan Palus <atler@pld-linux.org> 049ca74
- up to 535.54.03

* Sat Mar 25 2023 Jan Palus <atler@pld-linux.org> 0db7174
- up to 530.41.03

* Thu Feb 09 2023 Jan Palus <atler@pld-linux.org> 72888bf
- up to 525.89.02

* Sat Jan 21 2023 Jan Palus <atler@pld-linux.org> 6da9ca3
- up to 525.85.05

* Thu Jan 05 2023 Jan Palus <atler@pld-linux.org> afde829
- up to 525.78.01

* Mon Nov 28 2022 Jan Palus <atler@pld-linux.org> a827dcb
- up to 525.60.11

* Mon Oct 17 2022 Jan Palus <atler@pld-linux.org> bd76fce
- up to 520.56.06

* Wed Sep 21 2022 Jakub Bogusz <qboosh@pld-linux.org> 230f630
- versioned Obsoletes

* Wed Sep 21 2022 Jan Palus <atler@pld-linux.org> 6090a9a
- up to 515.76

